# JSONConfigParser - JSON config Parser Object
from configPy.jsonConfigParser import JSONConfigParser

# TXTConfigParser - TXT config Parser Object
from configPy.txtConfigParser import TXTConfigParser